<?php

/**
 * @file
 * Contains \Drupal\payment\Controller\CompletePayment.
 */

namespace Drupal\payment_authnet\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Drupal\payment\Entity\PaymentInterface;
use net\authorize\api\contract\v1 as AnetAPI;

use Drupal\payment_authnet\Exception\PaymentAuthnetApiException;

/**
 * Handles the "webhook" route.
 */
class Webhook extends ControllerBase {

  /**
   * Mollie calls this after the payment status has been changed. Mollie only
   * gives us an id leaving us with the responsibility to get the payment status.
   *
   * @param \Drupal\payment\Entity\PaymentInterface $payment
   *
   * @return
   */
  public function execute(PaymentInterface $payment) {
    // Get the id of the Authnet transaction from the request.
    $request = \Drupal::request();
    $authnet_transaction_id = $request->request->get('id');

    // Get the Authnet profile.
    $authnet_client = $payment->getPaymentMethod()->getMerchantAuthentication();

    try {
      // Load the Mollie transaction.
      $payment_authnet = $authnet_client->payments->get($authnet_transaction_id);

      // Payment status mapping.
      $payment_status = array(
        'open' => 'payment_pending',
        'cancelled' => 'payment_cancelled',
        'paid' => 'payment_success',
        'paidout' => 'payment_success',
        'refunded' => 'payment_refunded',
        'expired' => 'payment_expired',
      );

      $payment->getPaymentMethod()->updatePaymentStatus($payment, $payment_status[$payment_authnet->status]);
    }
    catch (PaymentAuthnetApiException $e) {
      drupal_set_message($e->getMessage(), 'error');
    }
    catch (Exception $e) {
      drupal_set_message($e->getMessage(), 'error');
    }

    return new Response();
  }

}
