<?php

/**
 * @file
 * Contains \Drupal\payment_authnet\Entity\AuthnetProfile\AuthnetProfileForm.
 */

namespace Drupal\payment_authnet\Entity\AuthnetProfile;

use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslationInterface;
use Drupal\plugin\Plugin\Plugin\PluginSelector\PluginSelectorManagerInterface;
use Drupal\plugin\PluginType\PluginTypeManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides the Mollie profile add/edit form.
 */
class AuthnetProfileForm extends EntityForm {

  /**
   * The Mollie profile storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $authnetProfileStorage;

  /**
   * The plugin selector manager.
   *
   * @var \Drupal\plugin\Plugin\Plugin\PluginSelector\PluginSelectorManagerInterface
   */
  protected $pluginSelectorManager;

  /**
   * The plugin type manager.
   *
   * @var \Drupal\plugin\PluginType\PluginTypeManager
   */
  protected $pluginTypeManager;

  /**
   * Constructs a new instance.
   *
   * @param \Drupal\Core\StringTranslation\TranslationInterface $string_translation
   *   The string translator.
   * @param \Drupal\Core\Entity\EntityStorageInterface $authnet_profile_storage
   *   The Authnet profile storage.
   * @param \Drupal\plugin\Plugin\Plugin\PluginSelector\PluginSelectorManagerInterface $plugin_selector_manager
   *   The plugin selector manager.
   * @param \Drupal\plugin\PluginType\PluginTypeManager $plugin_type_manager
   *   The plugin type manager.
   */
  public function __construct(TranslationInterface $string_translation, EntityStorageInterface $authnet_profile_storage, PluginSelectorManagerInterface $plugin_selector_manager, PluginTypeManager $plugin_type_manager) {
    $this->authnetProfileStorage = $authnet_profile_storage;
    $this->pluginSelectorManager = $plugin_selector_manager;
    $this->pluginTypeManager = $plugin_type_manager;
    $this->stringTranslation = $string_translation;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    /** @var \Drupal\Core\Entity\EntityManagerInterface $entity_manager */
    $entity_manager = $container->get('entity.manager');

    return new static($container->get('string_translation'), $entity_manager->getStorage('authnet_profile'), $container->get('plugin.manager.plugin.plugin_selector'), $container->get('plugin.plugin_type_manager'));
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    /** @var \Drupal\payment_authnet\Entity\AuthnetProfilesInterface $authnet_profile */
    $authnet_profile = $this->getEntity();
    $form['label'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Label'),
      '#default_value' => $authnet_profile->label(),
      '#maxlength' => 255,
      '#required' => TRUE,
    );
    $form['id'] = array(
      '#default_value' => $authnet_profile->id(),
      '#disabled' => !$authnet_profile->isNew(),
      '#machine_name' => array(
        'source' => array('label'),
        'exists' => array($this, 'AuthnetProfileIdExists'),
      ),
      '#maxlength' => 255,
      '#type' => 'machine_name',
      '#required' => TRUE,
    );
    $form['apiId'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('API Login ID'),
      '#default_value' => $authnet_profile->getApiId(),
      '#maxlength' => 255,
      '#required' => TRUE,
    );
    $form['apiTransactionKey'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Transaction Key'),
      '#default_value' => $authnet_profile->getApiTransactionKey(),
      '#maxlength' => 255,
      '#required' => TRUE,
    );
    $form['apiKey'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('API key'),
      '#description' => $this->t('It is also used in transactions as a prefix to transaction ID. If empty, <em>ref</em> prefix will be used.'),
      '#default_value' => $authnet_profile->getApiKey(),
      '#maxlength' => 10,
      '#required' => FALSE,
    );
    $sandbox_mode = $authnet_profile->getSandboxMode();
    $form['sandboxMode'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Sandbox Mode'),
      '#default_value' => is_null($sandbox_mode) ? TRUE : $sandbox_mode,
      '#description' => $this->t('Must be enabled for Sandbox Authorize.net Environment.'),
    );

    return parent::form($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function copyFormValuesToEntity(EntityInterface $authnet_profile, array $form, FormStateInterface $form_state) {
    /** @var \Drupal\payment_authnet\Entity\MolliePaymentInterface $mollie_profile */
    parent::copyFormValuesToEntity($authnet_profile, $form, $form_state);
    $values = $form_state->getValues();
    $authnet_profile->setId($values['id']);
    $authnet_profile->setLabel($values['label']);
    $authnet_profile->setApiId($values['apiId']);
    $authnet_profile->setApiTransactionKey($values['apiTransactionKey']);
    $authnet_profile->setApiKey($values['apiKey']);
    $authnet_profile->setSandboxMode($values['sandboxMode']);
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $authnet_profile = $this->getEntity();
    $authnet_profile->save();
    drupal_set_message($this->t('@label has been saved.', array(
      '@label' => $authnet_profile->label()
    )));
    $form_state->setRedirect('entity.authnet_profile.collection');
  }

  /**
   * Checks if a Authnet profile with a particular ID already exists.
   *
   * @param string $id
   *
   * @return bool
   */
  public function authnetProfileIdExists($id) {
    return (bool) $this->authnetProfileStorage->load($id);
  }

}
